==> ant-man-1.4.0.jar: META-INF/leiningen/com.hypaer/ant-man/README.md <==
# Ant-Man
[![Clojars Project](https://img.shields.io/clojars/v/com.hypaer/ant-man.svg)](https://clojars.org/com.hypaer/ant-man)

> <img src="resources/images/ant-man.png" width="66" />
>
> One question, is it too late to change the name?
>
> -Scott Lang

## Overview

Thin wrapper for [Ant Design](https://ant.design) React components with [Reagent](https://github.com/reagent-project/reagent)

Quick link to Ant Design introduction: https://ant.design/docs/react/introduce

## Documentation

* [API Documents](https://hypaer.github.io/ant-man/)

## Usage

Include Ant-Man in your `project.clj`

Include Ant Design CSS and JavaScript CDNs

```
https://cdnjs.cloudflare.com/ajax/libs/antd/${antd_version}/antd.min.css
```

```
https://cdnjs.cloudflare.com/ajax/libs/antd/${antd_version}/antd.min.js
```

Require and use in your project

```clojure
(:require [ant-man.core :as ant-man])

;; Input field
[ant-man/input {:value @your-reagent-atom
                :id "your-id"
                :placeholder "your-placeholder"}]


;; Select input field
(def type (reagent.core/atom nil)
(def types [{:id 1 :label "uno"}
            {:id 2 :label "dos"}]

[ant-man/select {:on-change (fn [val] (reset! type val))
                 :value @type
                 :style {:width "100%"}}
  (for [{:keys [label id]} types]
    [ant-man/select-option {:value id} label])]
```

## Helper functions

#### Child Enumeration
To enumerate over child elements with auto-key association use the `children` function located in `core`

```clojure
(:require [ant-man.core :as ant-man]
          [reagent.core :as r])

(def selection (r/atom nil))
(def example-collection [{:label "foo" :id 1} {:label "bar" :id 2}])

[ant-man/select {:on-change (fn [val] (reset! selection val))
                 :value @selection}
  (ant-man/children
    (fn [{:keys [label id]}]
      [ant-man/select-option {:value id} label])
    example-collection)]

```

## Development

To use in your project and develop this library simultaneously use [Leiningen Checkouts](https://github.com/technomancy/leiningen/blob/master/doc/TUTORIAL.md#checkout-dependencies) along with specifying a `src` path inside your `:cljsbuild` configuration. If you are using Figwheel and it is configured correctly changes made in Ant-Man will auto re-load.

#### Example:

```clojure
;; Specify path in your `project.clj`

:cljsbuild {:builds
            [{:id "dev"
              :source-paths ["src/cljs" "src/cljc" "checkouts/ant-man/src/cljs"]}]}
```

## License

Copyright © 2019 Hypaer

Distributed under the Eclipse Public License either version 1.0 or (at your option) any later version.

==> ant-man-1.5.0.jar: META-INF/leiningen/com.hypaer/ant-man/README.md <==
# Ant-Man
[![Clojars Project](https://img.shields.io/clojars/v/com.hypaer/ant-man.svg)](https://clojars.org/com.hypaer/ant-man)
[![Dependencies Status](https://versions.deps.co/hypaer/ant-man/status.svg)](https://versions.deps.co/hypaer/ant-man)
[![Build Status](https://travis-ci.org/hypaer/ant-man.svg?branch=master)](https://travis-ci.org/hypaer/ant-man)

> <img src="resources/images/ant-man.png" width="66" />
>
> One question, is it too late to change the name?
>
> -Scott Lang

## Overview

Thin ClojureScript wrapper for [Ant Design](https://ant.design) React components with [Reagent](https://github.com/reagent-project/reagent)

Quick link to Ant Design introduction: https://ant.design/docs/react/introduce

## Documentation

* [API Documents](https://hypaer.github.io/ant-man/)

## Usage

Include Ant-Man in your `project.clj`

Include Ant Design CSS and JavaScript CDNs

```
https://cdnjs.cloudflare.com/ajax/libs/antd/${antd_version}/antd.min.css
```

```
https://cdnjs.cloudflare.com/ajax/libs/antd/${antd_version}/antd.min.js
```

Require and use in your project

```clojure
(:require [ant-man.core :as ant-man])

;; Input field
[ant-man/input {:value @your-reagent-atom
                :id "your-id"
                :placeholder "your-placeholder"}]


;; Select input field
(def type (reagent.core/atom nil)
(def types [{:id 1 :label "uno"}
            {:id 2 :label "dos"}]

[ant-man/select {:on-change (fn [val] (reset! type val))
                 :value @type
                 :style {:width "100%"}}
  (for [{:keys [label id]} types]
    [ant-man/select-option {:value id} label])]
```

## Development

To use in your project and develop this library simultaneously use [Leiningen Checkouts](https://github.com/technomancy/leiningen/blob/master/doc/TUTORIAL.md#checkout-dependencies) along with specifying a `src` path inside your `:cljsbuild` configuration. If you are using Figwheel and it is configured correctly changes made in Ant-Man will auto re-load.

#### Example:

```clojure
;; Specify path in your `project.clj`

:cljsbuild {:builds
            [{:id "dev"
              :source-paths ["src/cljs" "src/cljc" "checkouts/ant-man/src/cljs"]}]}
```

## License

Copyright © 2019 Hypaer

Distributed under the Eclipse Public License either version 1.0 or (at your option) any later version.
